@@ -139,10 +139,13 @@ class System():
     async def a_update(self):
         last_update = time()
         while self.alive:
+            print('update %s' % self.type)
             new_update = time()
             if iscoroutinefunction(self.update):
+                print('update %s is awaitable' % self.type)
                 await self.update(new_update-last_update)
             else:
+                print('update %s is not awaitable' % self.type)
                 self.update(new_update-last_update)
                 await sleep(0)
 
